Addr class abstract

Implementers

Constructors

Addr.fromString(String address, Chain chain)
factory

Properties

hash Uint8List
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptPubKey Uint8List
no setter

Methods

encode(Chain chain) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLocking() Locking
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited