CryptoVault class

Constructors

CryptoVault({required CurveGate curve, required Ed25519Gate ed25519, required DigestGate digest, required KeyForge keyForge, required CodecGate codec})

Properties

codec CodecGate
final
curve CurveGate
final
digest DigestGate
final
ed25519 Ed25519Gate
final
hashCode int
The hash code for this object.
no setterinherited
keyForge KeyForge
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited