CurveGate class abstract

Implementations may use pure Dart math or native FFI/WASM bindings.

Constructors

CurveGate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

derivePublicKey(Uint8List privKey, {bool compressed = true}) Uint8List
ecdh(Uint8List privKey, Uint8List pubKey) Uint8List
ecdsaCompactToDer(Uint8List compact) Uint8List
ecdsaDerToCompact(Uint8List der) Uint8List
ecdsaNormalize(Uint8List signature) Uint8List
Normalizes to low-S form (BIP-62).
ecdsaRecover(Uint8List signature, int recId, Uint8List hash32, {bool compressed = true}) Uint8List
ecdsaSign(Uint8List hash32, Uint8List privKey) Uint8List
ecdsaSignRecoverable(Uint8List hash32, Uint8List privKey) → (Uint8List, int)
ecdsaVerify(Uint8List signature, Uint8List hash32, Uint8List pubKey) bool
isValidPrivateKey(Uint8List privKey) bool
load() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
privateKeyNegate(Uint8List privKey) Uint8List
privateKeyTweakAdd(Uint8List privKey, Uint8List scalar) Uint8List?
Returns null on overflow.
publicKeyTweakAdd(Uint8List pubKey, Uint8List scalar, {bool compressed = true}) Uint8List?
Returns null on overflow.
schnorrSign(Uint8List hash32, Uint8List privKey, {Uint8List? auxRand}) Uint8List
schnorrVerify(Uint8List signature, Uint8List hash32, Uint8List xPubKey) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited