DerivedSecretKey class

Inheritance

Constructors

DerivedSecretKey({required SecretKey secretKey, required Uint8List chainCode, required int depth, required int index, required int parentFingerprint})

Properties

chainCode Uint8List
finalinherited
depth int
finalinherited
fingerprint int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
identifier Uint8List
no setterinherited
index int
finalinherited
parentFingerprint int
finalinherited
publicKey PublicKey
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey SecretKey
final

Methods

derive(int index) DerivedSecretKey
override
deriveHardened(int index) DerivedKey
inherited
derivePath(String path) DerivedKey
inherited
encode({int version = 0x0488ADE4}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited