Mnemonic class

Constructors

Mnemonic(List<String> words)
Mnemonic.fromPhrase(String phrase)
factory
Mnemonic.generate({int strength = 128})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
phrase String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
words List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSeed({String passphrase = ''}) Uint8List
toString() String
A string representation of this object.
override
validate() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited