PayToWitnessPubKey class
P2WPKH: OP_0 <20>
- Implemented types
Constructors
- PayToWitnessPubKey(Uint8List pubKeyHash)
Properties
- compiled → Uint8List
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- pubKeyHash → Uint8List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- script → Script
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
match(
Script s) → PayToWitnessPubKey?