PushDataMatcher class
Matches any push of a given size, for pattern matching against scripts.
Constructors
- PushDataMatcher(int size)
Properties
Methods
-
compile(
) → Uint8List -
override
-
matches(
ScriptOp other) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited