TaprootScriptInput class

Script-path spend; witness = ...stack, script, controlBlock.

Inheritance

Constructors

TaprootScriptInput({required Outpoint prevOut, required List<Uint8List> stack, required Uint8List tapScript, required Uint8List controlBlock, int sequence = TxInput.sequenceFinal})

Properties

complete bool
no setteroverride
controlBlock Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
prevOut Outpoint
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptSig Uint8List
no setterinherited
sequence int
finalinherited
signedSize int
no setteroverride
stack List<Uint8List>
final
tapScript Uint8List
final
witness List<Uint8List>
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeTo(WireWriting writer) → void
inherited
writeWitness(WireWriting writer) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited