TxInput class abstract

Implementers

Constructors

TxInput()

Properties

complete bool
no setter
hashCode int
The hash code for this object.
no setterinherited
prevOut Outpoint
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptSig Uint8List
no setter
sequence int
no setter
signedSize int
no setter
witness List<Uint8List>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeTo(WireWriting writer) → void
writeWitness(WireWriting writer) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

sequenceFinal → const int