WitnessInput class abstract

Inheritance
Implementers

Constructors

WitnessInput({required Outpoint prevOut, int sequence = TxInput.sequenceFinal})

Properties

complete bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
prevOut Outpoint
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptSig Uint8List
no setteroverride
sequence int
final
signedSize int
no setterinherited
witness List<Uint8List>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeTo(WireWriting writer) → void
inherited
writeWitness(WireWriting writer) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited