AddrType enum

Inheritance
Available extensions

Values

p2pkh → const AddrType
p2sh → const AddrType
p2wpkh → const AddrType
p2wsh → const AddrType
p2tr → const AddrType
mweb → const AddrType

Litecoin MWEB stealth address (routing tag only; does NOT imply the canonical-chain script contract of the other types).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AddrType>
A constant List of the values in this enum, in order of their declaration.