AggregatedKey class

BIP-327 MuSig2 key aggregation: combines n public keys into one for n-of-n Schnorr multi-signing.

Constructors

AggregatedKey.fromKeys(List<PublicKey> keys)
Keys are used in the order provided, per BIP-327 sec. Key Aggregation. The aggregated key depends on the ordering - callers are responsible for providing a consistent, agreed-upon ordering across all signers.
factory

Properties

aggregatedKey PublicKey
final
hashCode int
The hash code for this object.
no setterinherited
publicKeys List<PublicKey>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xOnly Uint8List
32-byte x-only aggregated key for taproot.
no setter
yIsEven bool
no setter

Methods

coefficient(PublicKey key) Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited