type property
The kind of script being spent. Determines the sighash algorithm and the shape of the signed input that is attached.
Implementation
final AssemblerInputType type;
The kind of script being spent. Determines the sighash algorithm and the shape of the signed input that is attached.
final AssemblerInputType type;