BalanceInfo class

Constructors

BalanceInfo({required String address, required BigInt confirmed, BigInt? unconfirmed})

Properties

address String
final
confirmed BigInt
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total BigInt
no setter
unconfirmed BigInt
May be negative when unconfirmed spends exist.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited