BcmrIdentity class

BCMR identity: metadata (name, symbol, icon, decimals) for a CashToken category.

Constructors

BcmrIdentity({required Uint8List categoryId, required String name, required String symbol, int decimals = 0, String? description, String? iconUri})
const
BcmrIdentity.fromJson(Map<String, dynamic> json)
factory

Properties

categoryId Uint8List
32-byte token category ID.
final
decimals int
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
iconUri String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited