Bip44Paths class

Path pattern: m / purpose' / coin_type' / account'

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bip44(int coinType, {int account = 0}) String
bip49(int coinType, {int account = 0}) String
bip84(int coinType, {int account = 0}) String
bip86(int coinType, {int account = 0}) String