Bip69Ordering class
BIP-69: deterministic ordering to prevent wallet fingerprinting.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
compareInputs(
TxInput a, TxInput b) → int -
compareOutputs(
TxOutput a, TxOutput b) → int -
sortInputs(
List< TxInput> inputs) → void -
sortOutputs(
List< TxOutput> outputs) → void