ChainParams class

Available extensions

Constructors

ChainParams({required Chain chain, required String chainName, required String ticker, required String identifier, required int bip44CoinType, required List<AddrType> supportedAddrTypes, bool supportsSegwit = true, bool supportsTaproot = true, bool supportsMweb = false, bool usesForkId = false})
const

Properties

bech32Hrp String?
no setter
bip44CoinType int
final
chain Chain
final
chainName String
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
final
p2pkhPrefix int
no setter
p2shPrefix int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedAddrTypes List<AddrType>
final
supportsMweb bool
Litecoin MWEB capability flag. Parallel to supportsSegwit / supportsTaproot.
final
supportsSegwit bool
final
supportsTaproot bool
final
ticker String
final
usesForkId bool
BCH / BSV set this to modify sighash computation.
final
wifPrefix int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited