CoinSelection class

Constructors

CoinSelection({required List<SpendableUtxo> selected, required BigInt totalInput, required BigInt targetAmount, required BigInt fee})
const

Properties

change BigInt
no setter
fee BigInt
final
hashCode int
The hash code for this object.
no setterinherited
needsChange bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected List<SpendableUtxo>
final
targetAmount BigInt
final
totalInput BigInt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited