ElectrumLink class

Implemented types

Constructors

ElectrumLink({required String host, required int port, bool useSsl = true, int timeoutMs = 10000})

Properties

hashCode int
The hash code for this object.
no setterinherited
host String
final
isConnected bool
no setter
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeoutMs int
final
useSsl bool
final

Methods

broadcastTransaction(Uint8List rawTx) Future<String>
Broadcasts a signed tx; returns the txid.
override
connect() Future<void>
disconnect() Future<void>
estimateFeeRate({int targetBlocks = 6}) Future<int>
Fee rate in sat/vbyte for confirmation within targetBlocks.
override
getBalance(String address) Future<BalanceInfo>
override
getBlockHeight() Future<int>
override
getHistory(String address) Future<List<TxInfo>>
override
getRawTransaction(String txid) Future<Uint8List>
override
getTransaction(String txid) Future<TxInfo>
override
getUtxos(String address) Future<List<UtxoRef>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serverVersion({String clientName = 'coin-dart', String protocolMin = '1.4', String protocolMax = '1.4.2'}) Future<List<String>>
subscribeAddress(String address, void onStatus(String status)) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited