ExplorerLink class

Implemented types

Constructors

ExplorerLink({required String baseUrl, String? apiKey, int timeoutMs = 15000})

Properties

apiKey String?
final
baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeoutMs int
final

Methods

broadcastTransaction(Uint8List rawTx) Future<String>
Broadcasts a signed tx; returns the txid.
override
estimateFeeRate({int targetBlocks = 6}) Future<int>
Fee rate in sat/vbyte for confirmation within targetBlocks.
override
getBalance(String address) Future<BalanceInfo>
override
getBlockHeight() Future<int>
override
getHistory(String address) Future<List<TxInfo>>
override
getRawTransaction(String txid) Future<Uint8List>
override
getTransaction(String txid) Future<TxInfo>
override
getUtxos(String address) Future<List<UtxoRef>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited