ForkedBuilder class

Transaction builder with SIGHASH_FORKID support for BCH / BSV.

Constructors

ForkedBuilder({required ChainParams chainParams, int version = Tx.currentVersion, int locktime = 0})

Properties

chainParams ChainParams
final
hashCode int
The hash code for this object.
no setterinherited
inputCount int
no setter
locktime int
getter/setter pair
outputCount int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
final

Methods

addInput({required Outpoint outpoint, required BigInt value, required Uint8List scriptPubKey, int sequence = TxInput.sequenceFinal, SigHashType hashType = SigHashType.all}) → void
addOutput(TxOutput output) → void
buildUnsigned() Tx
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sigHash(Tx tx, int inputIndex, {int forkId = 0}) Uint8List
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited