ForkedHasher class

BIP-143-like sighash with the FORKID bit set for replay protection after the BCH/BSV chain split.

Implemented types

Constructors

ForkedHasher({int forkId = 0})
const

Properties

forkId int
Fork ID in the upper 24 bits of the sighash type word (0 for BCH/BSV).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hash(Tx tx, int inputIndex, SigHashType hashType, {Uint8List? prevScript, BigInt? amount}) Uint8List
Creates a combined hash code for a number of objects.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited