NoncePair class

A pair of public nonce points (33-byte compressed each).

Constructors

NoncePair({required Uint8List r1, required Uint8List r2})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
r1 Uint8List
final
r2 Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited