PartialSig class

One participant's partial signature in a MuSig2 session.

Constructors

PartialSig({required PublicKey signerKey, required Uint8List partialS})
const
PartialSig.sign({required Uint8List secretKey, required List<Uint8List> secretNonces, required NonceSession session})
BIP-327 Sign:
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
partialS Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signerKey PublicKey
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify(NonceSession session) bool
BIP-327 PartialSigVerify: sG == R_i + ea_i*P_i

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

combine(AggregatedKey aggKey, NonceSession session, List<PartialSig> partials) Uint8List
Combine partials into a BIP-340 Schnorr sig (64 bytes: R_x || s). s_final = sum(s_i) mod n.