PartialTx class abstract
Version-agnostic PSBT facade for constructing, inspecting, and finalizing partially signed transactions.
- Implementers
Constructors
- PartialTx.fromBase64(String encoded)
-
factory
- PartialTx.fromBytes(Uint8List bytes)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputCount → int
-
no setter
- outputCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unsignedTx → Tx?
-
The global unsigned transaction (v0 only).
no setter
- version → int
-
0 for BIP-174, 2 for BIP-370.
no setter
Methods
-
addInput(
{required Outpoint outpoint, Uint8List? witnessUtxoScript, BigInt? witnessUtxoValue, Tx? nonWitnessUtxo, int sequence}) → void -
addOutput(
{required Uint8List scriptPubKey, required BigInt value}) → void -
finalize(
) → Tx -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBase64(
) → String -
toBytes(
) → Uint8List -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited