PaymentCode class

80-byte payload:

[0]      version (0x01)
[1]      features (bit 0 = segwit)
[2..34]  compressed public key (33 bytes)
[35..66] chain code (32 bytes)
[67..79] reserved zeros

Constructors

PaymentCode(Uint8List payload)
PaymentCode.fromBase58(String encoded)
factory
PaymentCode.fromPublicKey({required Uint8List pubKey, required Uint8List chainCode, bool segwit = false})
factory

Properties

chainCode Uint8List
no setter
hashCode int
The hash code for this object.
no setteroverride
isSegwit bool
no setter
notificationPublicKey Uint8List
no setter
payload Uint8List
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

derivePublicKey(int index) PublicKey
BIP32 public child derivation:
isValid() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notificationAddress(Chain chain) String
toBase58() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

version → const int