PsbtCodec class

Low-level PSBT wire-format codec (BIP-174 / BIP-370).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Uint8List bytes) List<List<PsbtKeyValue>>
Decode into sections: global, input0, ..., output0, ....
encode(List<List<PsbtKeyValue>> sections) Uint8List
hasMagic(Uint8List bytes) bool