PsbtGlobal enum

PSBT global key types (BIP-174 Table 1).

Inheritance
Available extensions

Values

unsignedTx → const PsbtGlobal

0x00 - unsigned transaction (v0 only)

const PsbtGlobal(0x00)
xpub → const PsbtGlobal

0x01 - extended public key

const PsbtGlobal(0x01)
txVersion → const PsbtGlobal

0x02 - transaction version (v2)

const PsbtGlobal(0x02)
fallbackLocktime → const PsbtGlobal

0x03 - fallback locktime (v2)

const PsbtGlobal(0x03)
inputCount → const PsbtGlobal

0x04 - input count (v2)

const PsbtGlobal(0x04)
outputCount → const PsbtGlobal

0x05 - output count (v2)

const PsbtGlobal(0x05)
txModifiable → const PsbtGlobal

0x06 - tx modifiable flags (v2)

const PsbtGlobal(0x06)
version → const PsbtGlobal

0xfb - PSBT version

const PsbtGlobal(0xfb)
proprietary → const PsbtGlobal

0xfc - proprietary

const PsbtGlobal(0xfc)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
keyType int
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PsbtGlobal>
A constant List of the values in this enum, in order of their declaration.