PsbtOutputEntry enum

PSBT per-output key types (BIP-174 Table 3).

Inheritance
Available extensions

Values

redeemScript → const PsbtOutputEntry

0x00 - redeem script (P2SH)

const PsbtOutputEntry(0x00)
witnessScript → const PsbtOutputEntry

0x01 - witness script (P2WSH)

const PsbtOutputEntry(0x01)
bip32Derivation → const PsbtOutputEntry

0x02 - BIP-32 derivation path

const PsbtOutputEntry(0x02)
amount → const PsbtOutputEntry

0x03 - output amount (v2)

const PsbtOutputEntry(0x03)
script → const PsbtOutputEntry

0x04 - output scriptPubKey (v2)

const PsbtOutputEntry(0x04)
tapInternalKey → const PsbtOutputEntry

0x05 - taproot internal key

const PsbtOutputEntry(0x05)
tapTree → const PsbtOutputEntry

0x06 - taproot tree

const PsbtOutputEntry(0x06)
tapBip32Derivation → const PsbtOutputEntry

0x07 - taproot BIP-32 derivation

const PsbtOutputEntry(0x07)
proprietary → const PsbtOutputEntry

0xfc - proprietary

const PsbtOutputEntry(0xfc)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
keyType int
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PsbtOutputEntry>
A constant List of the values in this enum, in order of their declaration.