Rbf class
BIP-125 Replace-By-Fee helpers. RBF is signaled when any input has sequence < 0xfffffffe.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
bumpSequence(
int currentSequence) → int - Bump sequence for a replacement tx. BIP-125 rule 4 requires sequence >= original (miners mostly just check fee, though).
-
isRbfSignaled(
int sequence) → bool -
sequenceFor(
{bool enableRbf = true}) → int -
transactionIsRbf(
List< int> sequences) → bool
Constants
- sequenceFinal → const int
- sequenceLocktimeOnly → const int
- sequenceRbfDefault → const int