SpendableUtxo class

Constructors

SpendableUtxo({required Outpoint outpoint, required BigInt value, required Uint8List scriptPubKey, String? derivationPath, Uint8List? ownerPubKey, ChainParams? chainParams, int? blockHeight, bool isCoinbase = false})
const

Properties

blockHeight int?
final
chainParams ChainParams?
final
derivationPath String?
final
hashCode int
The hash code for this object.
no setterinherited
isCoinbase bool
final
isConfirmed bool
no setter
outpoint Outpoint
final
ownerPubKey Uint8List?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptPubKey Uint8List
final
txidHex String
no setter
value BigInt
final
vout int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited