TxInfo class

Constructors

TxInfo({required String txid, int? blockHeight, String? blockHash, BigInt? fee, Uint8List? rawTx, int? timestamp})
const

Properties

blockHash String?
final
blockHeight int?
final
fee BigInt?
final
hashCode int
The hash code for this object.
no setterinherited
isConfirmed bool
no setter
rawTx Uint8List?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int?
final
txid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited