TxSizeEstimate class

Constructors

TxSizeEstimate({required int baseSize, required int totalSize, required int weight, required int vsize})
const

Properties

baseSize int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalSize int
final
vsize int
weight / 4, rounded up.
final
weight int
BIP-141 weight units.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited