UtxoRef class

Constructors

UtxoRef({required String txid, required int vout, required BigInt value, required String scriptPubKeyHex, int? blockHeight})
const

Properties

blockHeight int?
final
hashCode int
The hash code for this object.
no setterinherited
isConfirmed bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptPubKeyHex String
final
txid String
final
value BigInt
final
vout int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited