WatchUtxo class

Constructors

WatchUtxo({required Outpoint outpoint, required BigInt value, required Uint8List scriptPubKey, int? blockHeight, bool spent = false})

Properties

blockHeight int?
final
hashCode int
The hash code for this object.
no setterinherited
isConfirmed bool
no setter
outpoint Outpoint
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptPubKey Uint8List
final
spent bool
getter/setter pair
value BigInt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited