Authorization class

EIP-7702 authorization tuple. Authorizes a contract's code to execute on behalf of an EOA.

Constructors

Authorization({required BigInt chainId, required Uint8List address, required BigInt nonce, int? v, Uint8List? r, Uint8List? s})

Properties

address Uint8List
final
chainId BigInt
final
hashCode int
The hash code for this object.
no setterinherited
nonce BigInt
final
r Uint8List?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
s Uint8List?
final
v int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(Uint8List privateKey) Authorization
signingHash() Uint8List
toRlpList() List
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited