BundlerLink class
ERC-4337 bundler JSON-RPC client.
Submits UserOperations to a bundler, which batches them into a single on-chain transaction via the EntryPoint contract.
Constructors
- BundlerLink({required String rpcUrl, String entryPointAddress = '0x5FF137D4b0FDCD49DcA30c7CF57E578a026d2789'})
Properties
- entryPointAddress → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rpcUrl → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
chainId(
) → Future< BigInt> -
estimateUserOperationGas(
UserIntent userOp) → Future< Map< String, BigInt> > -
formatEstimateRequest(
UserIntent userOp, {int id = 1}) → Map< String, dynamic> -
formatSendRequest(
UserIntent userOp, {int id = 1}) → Map< String, dynamic> -
getUserOperationByHash(
String hash) → Future< Map< String, dynamic> ?> -
getUserOperationReceipt(
String hash) → Future< Map< String, dynamic> ?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendUserOperation(
UserIntent userOp) → Future< String> -
supportedEntryPoints(
) → Future< List< String> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited