ChainReader class

Constructors

ChainReader(Future _rpc(String method, List? params))

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Map<String, dynamic> callParams, {String block = 'latest'}) Future<Uint8List>
estimateGas(Map<String, dynamic> txParams) Future<BigInt>
getBalance(EvmAddr address, {String block = 'latest'}) Future<BigInt>
Balance in wei.
getBlockByHash(String blockHash, {bool fullTransactions = false}) Future<Map<String, dynamic>?>
getBlockByNumber(String blockTag, {bool fullTransactions = false}) Future<Map<String, dynamic>?>
getBlockNumber() Future<BigInt>
getChainId() Future<BigInt>
getCode(EvmAddr address, {String block = 'latest'}) Future<Uint8List>
getFeeHistory(int blockCount, String newestBlock, List<double> rewardPercentiles) Future<Map<String, dynamic>>
getGasPrice() Future<BigInt>
getLogs(Map<String, dynamic> filter) Future<List<Map<String, dynamic>>>
getMaxPriorityFeePerGas() Future<BigInt>
getStorageAt(EvmAddr address, BigInt slot, {String block = 'latest'}) Future<Uint8List>
getTransactionByHash(String txHash) Future<Map<String, dynamic>?>
getTransactionCount(EvmAddr address, {String block = 'latest'}) Future<BigInt>
getTransactionReceipt(String txHash) Future<Map<String, dynamic>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited