CollectibleToken class

ERC-721 interface.

Constructors

CollectibleToken(DeployedContract contract)
CollectibleToken.at(EvmAddr address)
factory
CollectibleToken.atHex(String address)
factory

Properties

address EvmAddr
no setter
contract DeployedContract
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

approve(EvmAddr to, BigInt tokenId) InvokeBuilder
balanceOf(EvmAddr owner) CallBuilder
getApproved(BigInt tokenId) CallBuilder
isApprovedForAll(EvmAddr owner, EvmAddr operator_) CallBuilder
name() CallBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ownerOf(BigInt tokenId) CallBuilder
safeTransferFrom(EvmAddr from, EvmAddr to, BigInt tokenId, [Uint8List? data]) InvokeBuilder
setApprovalForAll(EvmAddr operator_, bool approved) InvokeBuilder
symbol() CallBuilder
tokenURI(BigInt tokenId) CallBuilder
toString() String
A string representation of this object.
inherited
transferFrom(EvmAddr from, EvmAddr to, BigInt tokenId) InvokeBuilder

Operators

operator ==(Object other) bool
The equality operator.
inherited