DeployedContract class

Constructors

DeployedContract({required EvmAddr address, required ParsedAbi abi})
DeployedContract.fromJson({required String address, required String abiJson})
factory

Properties

abi ParsedAbi
final
address EvmAddr
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeResult(String functionName, Uint8List data) List
encodeCall(String functionName, List args) Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String functionName, [List args = const []]) CallBuilder
simulate(String functionName, [List args = const []]) CallBuilder
Dry-run a write function via eth_call (no transaction submitted).
toString() String
A string representation of this object.
inherited
write(String functionName, [List args = const []]) InvokeBuilder

Operators

operator ==(Object other) bool
The equality operator.
inherited