Envelope class

Constructors

Envelope({required EnvelopeKind kind, Uint8List? to, BigInt? value, Uint8List? data, BigInt? gasLimit, BigInt? nonce, BigInt? chainId, BigInt? gasPrice, BigInt? maxFeePerGas, BigInt? maxPriorityFeePerGas, BigInt? maxFeePerBlobGas, List<Uint8List>? blobVersionedHashes, List<BlobData>? blobs, List<AccessListEntry>? accessList, List<Authorization>? authorizationList, int? v, Uint8List? r, Uint8List? s})

Properties

accessList List<AccessListEntry>?
final
authorizationList List<Authorization>?
final
blobs List<BlobData>?
Sidecar blobs -- not included in the signing hash.
final
blobVersionedHashes List<Uint8List>?
final
chainId BigInt
final
data Uint8List
final
gasLimit BigInt
final
gasPrice BigInt?
final
hashCode int
The hash code for this object.
no setterinherited
kind EnvelopeKind
final
maxFeePerBlobGas BigInt?
final
maxFeePerGas BigInt?
final
maxPriorityFeePerGas BigInt?
final
nonce BigInt
final
r Uint8List?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
s Uint8List?
final
to Uint8List?
Null for contract creation.
final
v int?
final
value BigInt
final

Methods

hash() Uint8List
Creates a combined hash code for a number of objects.
override
hashHex() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serialize the signed transaction for broadcast. Legacy: plain RLP. Typed: typeId || rlp(fields ++ sig).
signingHash() Uint8List
toString() String
A string representation of this object.
inherited
withSignature({required int v, required Uint8List r, required Uint8List s}) Envelope

Operators

operator ==(Object other) bool
The equality operator.
inherited