EvmChain class

Constructors

EvmChain({required int chainId, required String name, required String symbol, required List<String> rpcUrls, List<String> explorerUrls = const [], int decimals = 18})
const

Properties

chainId int
final
decimals int
Almost always 18.
final
explorerUrls List<String>
final
hashCode int
The hash code for this object.
no setteroverride
name String
final
rpcUrls List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override