EvmChains class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

byId(int chainId) EvmChain?

Constants

all → const Map<int, EvmChain>
arbitrum → const EvmChain
avalanche → const EvmChain
base → const EvmChain
bsc → const EvmChain
ethereum → const EvmChain
optimism → const EvmChain
polygon → const EvmChain
sepolia → const EvmChain