GasSponsor class abstract

ERC-4337 paymaster -- sponsors gas so users can transact without ETH.

Implementers

Constructors

GasSponsor()

Properties

hashCode int
The hash code for this object.
no setterinherited
paymasterAddress String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPaymasterData(UserIntent userOp) Future<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
willSponsor(UserIntent userOp) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited