HardwareKeyAgent class abstract

Hardware signing device (Ledger, Trezor, etc.). The private key never leaves the device.

Implemented types
Implementers

Constructors

HardwareKeyAgent()

Properties

derivationPath String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() Future<void>
disconnect() Future<void>
getAddress() Future<EvmAddr>
inherited
getPublicKey() Future<Uint8List>
isConnected() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signHash(Uint8List hash32) Future<Uint8List>
Sign a raw 32-byte hash. Returns 65-byte signature (r + s + v).
inherited
signMessage(Uint8List message) Future<Uint8List>
EIP-191 personal_sign. Returns 65-byte signature (r + s + v).
inherited
signTransaction(Envelope envelope) Future<Uint8List>
inherited
signTypedData(Map<String, dynamic> typedData) Future<Uint8List>
EIP-712 typed data signing. Returns 65-byte signature (r + s + v).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited