InvokeBuilder class

Constructors

InvokeBuilder({required DeployedContract contract, required SolFunction function_, required List args, EvmAddr? from, BigInt? value, BigInt? gasLimit, BigInt? nonce, BigInt? maxFeePerGas, BigInt? maxPriorityFeePerGas, BigInt? gasPrice, BigInt? chainId})

Properties

args List
final
chainId BigInt?
getter/setter pair
contract DeployedContract
final
from EvmAddr?
getter/setter pair
function_ SolFunction
final
gasLimit BigInt?
getter/setter pair
gasPrice BigInt?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxFeePerGas BigInt?
getter/setter pair
maxPriorityFeePerGas BigInt?
getter/setter pair
nonce BigInt?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value BigInt?
getter/setter pair

Methods

encodeCalldata() Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEnvelope() Envelope
toString() String
A string representation of this object.
inherited
toTransactionParams() Map<String, dynamic>
withEip1559Fees({required BigInt maxFee, required BigInt maxPriorityFee}) InvokeBuilder
withFrom(EvmAddr addr) InvokeBuilder
withGasLimit(BigInt limit) InvokeBuilder
withNonce(BigInt n) InvokeBuilder
withValue(BigInt val) InvokeBuilder

Operators

operator ==(Object other) bool
The equality operator.
inherited