JsonRpcLink class

Constructors

JsonRpcLink({required String url, Duration timeout = const Duration(seconds: 30)})

Properties

hashCode int
The hash code for this object.
no setterinherited
isWebSocket bool
no setter
nextId int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final
url String
final

Methods

batch(List<(String, List?)> requests) Future<List>
call(String method, [List? params]) Future
close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe(String method, [List? params]) Stream
toString() String
A string representation of this object.
inherited
unsubscribe(String subscriptionId) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited