MultichainNames class

ENSIP-9 multi-coin address resolution.

Resolves ENS names to addresses on any chain via SLIP-44 coin types.

Constructors

MultichainNames(String name)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
node Uint8List
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAddress(int coinType) Future<Uint8List?>
getEvmAddress(int chainId) Future<Uint8List?>
ENSIP-11: EVM coin type is 0x80000000 | chainId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAddress(int coinType, Uint8List address) Future<void>
setEvmAddress(int chainId, Uint8List address) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

coinTypeToChainId(int coinType) int?
encodeMultichainAddrCall(Uint8List node, int coinType) Uint8List
encodeSetAddrCall(Uint8List node, int coinType, Uint8List address) Uint8List

Constants

atom → const int
btc → const int
doge → const int
dot → const int
eth → const int
ltc → const int
matic → const int
sol → const int
trx → const int
xrp → const int