NameRecords class

ENS text records and contenthash resolution.

Constructors

NameRecords(String name)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
node Uint8List
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAbi() Future<Uint8List?>
getContentHash() Future<Uint8List?>
getText(String key) Future<String?>
getTextKeys() Future<List<String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setContentHash(Uint8List hash) Future<void>
setText(String key, String value) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited