ParsedAbi class

Constructors

ParsedAbi({required List<SolFunction> functions, required List<SolEvent> events, required List<SolError> errors})

Properties

errors List<SolError>
final
events List<SolEvent>
final
functions List<SolFunction>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

error(String name) SolError?
event(String name) SolEvent?
function(String name) SolFunction?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited