SimpleDelegatedAccount class

Simple EOA-owned smart account reference implementation.

Implemented types

Constructors

SimpleDelegatedAccount({required EvmAddr address, required EvmAddr ownerAddress, required EvmAddr factoryAddress})

Properties

address EvmAddr
final
factoryAddress EvmAddr
final
hashCode int
The hash code for this object.
no setterinherited
ownerAddress EvmAddr
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildInitCode() Uint8List
override
buildUserIntent({required EvmAddr target, required BigInt value, required Uint8List data, BigInt? maxFeePerGas, BigInt? maxPriorityFeePerGas}) Future<UserIntent>
override
encodeBatchExecute(List<EvmAddr> targets, List<BigInt> values, List<Uint8List> datas) Uint8List
override
encodeExecute(EvmAddr target, BigInt value, Uint8List data) Uint8List
override
getNonce() Future<BigInt>
override
isDeployed() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signUserOpHash(Uint8List hash) Future<Uint8List>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited