SolCodec class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decodeParameters(List<SolType> types, Uint8List data) List
decodeResult(List<SolType> types, Uint8List data) List
encodeCall(String sig, List<SolType> types, List values) Uint8List
encodePacked(List<SolType> types, List values) Uint8List
Non-standard tight packing (abi.encodePacked). Static types use native width (no padding), dynamic types have no length prefix, arrays are packed element-by-element.
encodeParameters(List<SolType> types, List values) Uint8List
selector(String signature) Uint8List