SolFixedBytes class

Fixed-size bytes1 .. bytes32.

Inheritance

Constructors

SolFixedBytes(int length)

Properties

hashCode int
The hash code for this object.
no setterinherited
isDynamic bool
no setteroverride
length int
final
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Uint8List data, int offset) → (dynamic, int)
ABI-decode from data at byte offset. Returns (decoded value, bytes consumed from head).
override
encode(dynamic value) Uint8List
ABI-encode value as a 32-byte-aligned Uint8List. For dynamic types, returns the tail; the caller places the offset in the head.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited