TokenAmount class

Constructors

TokenAmount.fromEther(num ether)
factory
TokenAmount.fromEtherString(String ether)
Full precision from a decimal string (e.g. "1.5").
factory
TokenAmount.fromGwei(num gwei)
factory
TokenAmount.fromWei(BigInt wei)
factory
TokenAmount.fromWeiInt(int wei)
factory

Properties

ether double
May lose precision for very large values.
no setter
gwei BigInt
no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wei BigInt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEtherString() String
Up to 18 decimal places, trailing zeros stripped.
toString() String
A string representation of this object.
override

Operators

operator *(int scalar) TokenAmount
operator +(TokenAmount other) TokenAmount
operator -(TokenAmount other) TokenAmount
operator <(TokenAmount other) bool
operator <=(TokenAmount other) bool
operator ==(Object other) bool
The equality operator.
override
operator >(TokenAmount other) bool
operator >=(TokenAmount other) bool