TrezorAgent class

Inheritance

Constructors

TrezorAgent({String derivationPath = "m/44'/60'/0'/0/0"})

Properties

derivationPath String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() Future<void>
override
disconnect() Future<void>
override
getAddress() Future<EvmAddr>
override
getPublicKey() Future<Uint8List>
override
isConnected() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signHash(Uint8List hash32) Future<Uint8List>
Sign a raw 32-byte hash. Returns 65-byte signature (r + s + v).
override
signMessage(Uint8List message) Future<Uint8List>
EIP-191 personal_sign. Returns 65-byte signature (r + s + v).
override
signTransaction(Envelope envelope) Future<Uint8List>
override
signTypedData(Map<String, dynamic> typedData) Future<Uint8List>
EIP-712 typed data signing. Returns 65-byte signature (r + s + v).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited