TypedPayload class

EIP-712 typed structured data hashing and signing.

Constructors

TypedPayload({required Map<String, dynamic> domain, required String primaryType, required Map<String, List<Map<String, String>>> types, required Map<String, dynamic> message})
TypedPayload.fromJson(String jsonStr)
factory

Properties

domain Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
message Map<String, dynamic>
final
primaryType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
types Map<String, List<Map<String, String>>>
final

Methods

domainSeparator() Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(SecretKey key) Uint8List
Returns 65 bytes: r (32) + s (32) + v (1).
signingHash() Uint8List
keccak256("\x19\x01" || domainSeparator || structHash).
structHash() Uint8List
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited