UserIntent class

ERC-4337 UserOperation struct.

Constructors

UserIntent({required EvmAddr sender, BigInt? nonce, Uint8List? initCode, Uint8List? callData, BigInt? callGasLimit, BigInt? verificationGasLimit, BigInt? preVerificationGas, BigInt? maxFeePerGas, BigInt? maxPriorityFeePerGas, Uint8List? paymasterAndData, Uint8List? signature})

Properties

callData Uint8List
getter/setter pair
callGasLimit BigInt
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initCode Uint8List
getter/setter pair
maxFeePerGas BigInt
getter/setter pair
maxPriorityFeePerGas BigInt
getter/setter pair
nonce BigInt
getter/setter pair
paymasterAndData Uint8List
getter/setter pair
preVerificationGas BigInt
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender EvmAddr
final
signature Uint8List
getter/setter pair
verificationGasLimit BigInt
getter/setter pair

Methods

hash({required EvmAddr entryPoint, required BigInt chainId}) Uint8List
Creates a combined hash code for a number of objects.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack() Uint8List
toJson() Map<String, String>
toString() String
A string representation of this object.
inherited
withSignature(Uint8List sig) UserIntent

Operators

operator ==(Object other) bool
The equality operator.
inherited