VerifyingGasSponsor class
Verifying paymaster that checks a signature from a trusted off-chain signer.
- Implemented types
Constructors
- VerifyingGasSponsor({required String paymasterAddress, required String signerServiceUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- paymasterAddress → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signerServiceUrl → String
-
final
Methods
-
buildPaymasterAndData(
{required BigInt validUntil, required BigInt validAfter, required Uint8List signature}) → Uint8List -
getPaymasterData(
UserIntent userOp) → Future< Uint8List> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sponsor(
UserIntent userOp) → Future< UserIntent> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
willSponsor(
UserIntent userOp) → Future< bool> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited