ProtoReader class

Constructors

ProtoReader(Uint8List _buf)

Properties

hashCode int
The hash code for this object.
no setterinherited
hasMore bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readLenDelim() Uint8List
readRawVarint() int
readString() String
readTag() → (int, int)
skip(int wireType) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited