ProtoWriter class

Constructors

ProtoWriter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
toString() String
A string representation of this object.
inherited
writeBool(int fieldNum, bool value) → void
writeRepeatedUint32(int fieldNum, List<int> values) → void
writeString(int fieldNum, String value) → void
writeVarint(int value) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited