TrezorBridgeAdapter class
- Inheritance
-
- Object
- HardwareDevice
- TrezorDevice
- TrezorBridgeAdapter
Constructors
- TrezorBridgeAdapter({String baseUrl = 'http://127.0.0.1:21325', Client? client})
Properties
- connectedDevice → TrezorHardwareWalletDevice?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
int msgType, Uint8List payload) → Future< (int, Uint8List)> -
override
-
connectDevice(
) → Future< void> -
override
-
disconnect(
) → Future< void> -
override
-
getPublicKey(
{required List< int> addressN, Future<String> onPinRequest()?, Future<String> onPassphraseRequest()?}) → Future<TrezorPublicKey> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scanForDevices(
) → Future< List< HardwareDevice> > -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited