TrezorHardwareWalletDevice class

Inheritance

Constructors

TrezorHardwareWalletDevice({required String hidPath})

Properties

features TrezorFeatures?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hidPath String
final
isConnected bool
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(int msgType, Uint8List payload) Future<(int, Uint8List)>
override
connectDevice() Future<void>
override
disconnect() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanForDevices() Future<List<HardwareDevice>>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited