MoneroKeys class

Spend and view key pairs on Ed25519. From a seed: spendPriv = reduce(seed), viewPriv = reduce(keccak(spendPriv)), public keys = scalar * G.

Constructors

MoneroKeys.fromSeed(Uint8List seed)
factory
MoneroKeys.fromSpendKey(Uint8List privateSpendKey)
factory
MoneroKeys.generate()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
privateSpendKey Uint8List
final
privateSpendKeyHex String
no setter
privateViewKey Uint8List
final
privateViewKeyHex String
no setter
publicSpendKey Uint8List
final
publicSpendKeyHex String
no setter
publicViewKey Uint8List
final
publicViewKeyHex String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited