MoneroTxInput class

Constructors

MoneroTxInput({required List<RingMember> ring, required Uint8List keyImage, int realIndex = -1})

Properties

hashCode int
The hash code for this object.
no setterinherited
keyImage Uint8List
final
realIndex int
Private knowledge of the sender; never serialized on chain.
final
ring List<RingMember>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited