PedersenCommitment class

C = amount * H + mask * G. H = hashToPoint(G), so DL(G,H) is unknown.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

h Uint8List
The alternate generator H = hashToPoint(G). Public for testing.
no setter

Static Methods

commit(BigInt amount, Uint8List mask) Uint8List
verify(Uint8List commitment, BigInt amount, Uint8List mask) bool