WcLinkModeMessage class

A link-mode (deep-link) message: the topic it targets and the out-of-band envelope (a type-2 base64url envelope) it carries.

Constructors

WcLinkModeMessage({required String topic, required String envelope})
const

Properties

envelope String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topic String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited