WcUri class

WalletConnect wc: URI parsing/serialization (EIP-1328), v1 and v2.

v1: wc:{topic}@1?bridge={urlencoded}&key={hex} v2: wc:{topic}@2?relay-protocol={p}&symKey={hex}

Constructors

WcUri({required String topic, required int version, String? bridge, String? key, String? relayProtocol, String? symKey})
const

Properties

bridge String?
final
hashCode int
The hash code for this object.
no setterinherited
key String?
final
relayProtocol String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symKey String?
final
topic String
final
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String uri) WcUri