WcVerifyKey class

The Verify service's ES256 public key (a JWK), plus its expiresAt.

Constructors

WcVerifyKey({required BigInt qx, required BigInt qy, int? expiresAt})
WcVerifyKey.fromPublicKeyJson(Map<String, dynamic> j)
Parse the /v2/public-key response: {publicKey: {crv,x,y,...}, expiresAt}.
factory

Properties

expiresAt int?
final
hashCode int
The hash code for this object.
no setterinherited
qx BigInt
final
qy BigInt
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited