WcVerifyStatus enum
The result of validating an attestation against a declared origin.
Values
- valid → const WcVerifyStatus
-
Signature valid and the attested origin matches the peer's.
- invalid → const WcVerifyStatus
-
Signature invalid, or the attested origin does not match.
- scam → const WcVerifyStatus
-
The Verify service flagged the origin as a known scam.
- unknown → const WcVerifyStatus
-
No attestation present / could not be evaluated.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WcVerifyStatus> - A constant List of the values in this enum, in order of their declaration.