KeyForge class abstract
Constructors
- KeyForge()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deriveChild(
{required Uint8List parentKey, required Uint8List parentChainCode, required int index, required bool hardened, required bool isPrivate, required Uint8List parentPublicKey}) → DerivedKeyMaterial -
masterFromSeed(
Uint8List seed) → DerivedKeyMaterial -
mnemonicToSeed(
String mnemonic, {String passphrase = ''}) → Uint8List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited