BcmrRegistry class
BCMR registry document containing token identity entries.
Constructors
-
BcmrRegistry({String version = '2.0.0', List<
BcmrIdentity> identities = const []}) -
const
-
BcmrRegistry.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
identities
→ List<
BcmrIdentity> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
Schema version (e.g. "2.0.0").
final
Methods
-
findByCategory(
Uint8List categoryId) → BcmrIdentity? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited