Bip44Paths class
Path pattern: m / purpose' / coin_type' / account'
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- bitcoin → const String
- bitcoinCash → const String
- bitcoinCashTestnet → const String
- bitcoinNativeSegwit → const String
- bitcoinSegwitCompat → const String
- bitcoinSv → const String
- bitcoinSvTestnet → const String
- bitcoinTaproot → const String
- bitcoinTestnet → const String
- bitcoinTestnetNativeSegwit → const String
- bitcoinTestnetSegwitCompat → const String
- bitcoinTestnetTaproot → const String
- dash → const String
- dashTestnet → const String
- dogecoin → const String
- dogecoinTestnet → const String
- litecoin → const String
- litecoinNativeSegwit → const String
- litecoinSegwitCompat → const String
- litecoinTestnet → const String
- monero → const String
- moneroTestnet → const String
- peercoin → const String
- peercoinTestnet → const String