FeeEstimator class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
estimateFee({required TxSizeEstimate sizeEstimate, required int satPerVbyte})
→ BigInt
-
-
estimateSize({int numP2pkhInputs = 0, int numP2shInputs = 0, int numP2wpkhInputs = 0, int numP2trInputs = 0, int numP2pkhOutputs = 0, int numP2shOutputs = 0, int numP2wpkhOutputs = 0, int numP2trOutputs = 0})
→ TxSizeEstimate
-
-
quickEstimate({required int numInputs, required int numOutputs, required int satPerVbyte, bool segwit = true})
→ BigInt
-
Quick estimate assuming uniform input/output types.