PartialTxV1 class

BIP-174 PSBT version 0 implementation.

Implemented types

Constructors

PartialTxV1({Tx? unsignedTx})
PartialTxV1.fromBytes(Uint8List bytes)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inputCount int
no setteroverride
outputCount int
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unsignedTx Tx?
The global unsigned transaction (v0 only).
no setteroverride
version int
0 for BIP-174, 2 for BIP-370.
no setteroverride

Methods

addInput({required Outpoint outpoint, Uint8List? witnessUtxoScript, BigInt? witnessUtxoValue, Tx? nonWitnessUtxo, int sequence = 0xffffffff}) → void
override
addInputEntry(int index, PsbtKeyValue entry) → void
addOutput({required Uint8List scriptPubKey, required BigInt value}) → void
override
finalize() Tx
override
getInputSection(int index) List<PsbtKeyValue>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64() String
override
toBytes() Uint8List
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited