PartialTxV2 class
BIP-370 PSBT version 2 implementation. Per-input and per-output fields live directly in their own sections instead of inside a global unsigned tx.
- Implemented types
Constructors
- PartialTxV2({int txVersion = 2, int locktime = 0})
- PartialTxV2.fromBytes(Uint8List bytes)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputCount → int
-
no setteroverride
- locktime → int
-
no setter
- outputCount → int
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- txVersion → int
-
no setter
- unsignedTx → Tx?
-
The global unsigned transaction (v0 only).
no setteroverride
- version → int
-
0 for BIP-174, 2 for BIP-370.
no setteroverride
Methods
-
addInput(
{required Outpoint outpoint, Uint8List? witnessUtxoScript, BigInt? witnessUtxoValue, Tx? nonWitnessUtxo, int sequence = 0xffffffff}) → void -
override
-
addInputEntry(
int index, PsbtKeyValue entry) → void -
addOutput(
{required Uint8List scriptPubKey, required BigInt value}) → void -
override
-
finalize(
) → Tx -
override
-
getInputSection(
int index) → List< PsbtKeyValue> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBase64(
) → String -
override
-
toBytes(
) → Uint8List -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited