PsbtInputEntry enum
PSBT per-input key types (BIP-174 Table 2).
Values
- nonWitnessUtxo → const PsbtInputEntry
-
0x00 - non-witness UTXO (full prev tx)
const PsbtInputEntry(0x00) - witnessUtxo → const PsbtInputEntry
-
0x01 - witness UTXO (single output)
const PsbtInputEntry(0x01) - partialSig → const PsbtInputEntry
-
0x02 - partial signature
const PsbtInputEntry(0x02) - sighashType → const PsbtInputEntry
-
0x03 - sighash type
const PsbtInputEntry(0x03) - redeemScript → const PsbtInputEntry
-
0x04 - redeem script (P2SH)
const PsbtInputEntry(0x04) - witnessScript → const PsbtInputEntry
-
0x05 - witness script (P2WSH)
const PsbtInputEntry(0x05) - bip32Derivation → const PsbtInputEntry
-
0x06 - BIP-32 derivation path
const PsbtInputEntry(0x06) - finalScriptSig → const PsbtInputEntry
-
0x07 - finalized scriptSig
const PsbtInputEntry(0x07) - finalScriptWitness → const PsbtInputEntry
-
0x08 - finalized witness
const PsbtInputEntry(0x08) - previousTxid → const PsbtInputEntry
-
0x0e - previous txid (v2)
const PsbtInputEntry(0x0e) - outputIndex → const PsbtInputEntry
-
0x0f - previous output index (v2)
const PsbtInputEntry(0x0f) - sequence → const PsbtInputEntry
-
0x10 - sequence number (v2)
const PsbtInputEntry(0x10) - requiredTimeLocktime → const PsbtInputEntry
-
0x11 - required time locktime (v2)
const PsbtInputEntry(0x11) - requiredHeightLocktime → const PsbtInputEntry
-
0x12 - required height locktime (v2)
const PsbtInputEntry(0x12) - tapKeySig → const PsbtInputEntry
-
0x13 - taproot key spend sig
const PsbtInputEntry(0x13) - tapScriptSig → const PsbtInputEntry
-
0x14 - taproot script spend sig
const PsbtInputEntry(0x14) - tapLeafScript → const PsbtInputEntry
-
0x15 - taproot leaf script
const PsbtInputEntry(0x15) - tapBip32Derivation → const PsbtInputEntry
-
0x16 - taproot BIP-32 derivation
const PsbtInputEntry(0x16) - tapInternalKey → const PsbtInputEntry
-
0x17 - taproot internal key
const PsbtInputEntry(0x17) - tapMerkleRoot → const PsbtInputEntry
-
0x18 - taproot Merkle root
const PsbtInputEntry(0x18) - proprietary → const PsbtInputEntry
-
0xfc - proprietary
const PsbtInputEntry(0xfc)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- keyType → int
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PsbtInputEntry> - A constant List of the values in this enum, in order of their declaration.