PsbtSigner class

Computes sighashes and attaches partial signatures to a PartialTx.

Constructors

PsbtSigner({required PartialTx psbt, SigHashType defaultHashType = SigHashType.all})

Properties

defaultHashType SigHashType
final
hashCode int
The hash code for this object.
no setterinherited
psbt PartialTx
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(SignerCallback signer) → void
signAsync(AsyncSignerCallback signer) Future<void>
signInput(int index, SignerCallback signer) → void
signInputAsync(int index, AsyncSignerCallback signer) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited