WatchOnlyTracker class
Tracks UTXOs without private keys -- for balance monitoring or building transactions before offline signing.
Constructors
- WatchOnlyTracker({required ChainParams chainParams})
Properties
- balance → BigInt
-
no setter
- chainParams → ChainParams
-
final
- confirmedBalance → BigInt
-
no setter
-
confirmedUnspent
→ List<
WatchUtxo> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
no setter
-
unspent
→ List<
WatchUtxo> -
no setter
- unspentCount → int
-
no setter
Methods
-
add(
WatchUtxo utxo) → void -
markSpent(
Outpoint outpoint) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
Outpoint outpoint) → void -
toSpendable(
) → List< SpendableUtxo> - Converts to SpendableUtxo list (without owner key info).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited