AccessListEntry class
EIP-2930 access list entry.
Constructors
-
AccessListEntry({required Uint8List address, List<
Uint8List> ? storageKeys}) -
AccessListEntry.fromHex({required String address, List<
String> ? storageKeys}) -
factory
Properties
- address → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storageKeys
→ List<
Uint8List> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toRlpList(
) → List -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited