Authorization class
EIP-7702 authorization tuple. Authorizes a contract's code to execute on behalf of an EOA.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sign(
Uint8List privateKey) → Authorization -
signingHash(
) → Uint8List -
toRlpList(
) → List -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited