BlobData class
EIP-4844 blob data. 128 KiB chunks carried by type-3 transactions. KZG commitment/proof must be supplied externally (via a KZG library or precomputed values). computeVersionedHash derives the hash locally.
Constructors
Properties
- commitment → Uint8List?
-
final
- data → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- proof → Uint8List?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- versionedHash → Uint8List?
-
final
Methods
-
computeCommitment(
) → Uint8List -
computeProof(
) → Uint8List -
computeVersionedHash(
) → Uint8List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited