CallBuilder class
Constructors
- CallBuilder({required DeployedContract contract, required SolFunction function_, required List args, EvmAddr? from, String blockTag = 'latest'})
Properties
- args → List
-
final
- blockTag ↔ String
-
getter/setter pair
- contract → DeployedContract
-
final
- from ↔ EvmAddr?
-
getter/setter pair
- function_ → SolFunction
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
atBlock(
String tag) → CallBuilder -
call(
Future< String> callFn(Map<String, dynamic> params, String blockTag)) → Future<List> -
encodeCalldata(
) → Uint8List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCallParams(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
withFrom(
EvmAddr addr) → CallBuilder
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited