ChainWriter class

Constructors

ChainWriter({required Future rpc(String method, List? params), required ChainReader reader, required KeyAgent signer})

Properties

hashCode int
The hash code for this object.
no setterinherited
reader ChainReader
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signer KeyAgent
final

Methods

getAddress() Future<EvmAddr>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendRawTransaction(Uint8List signedTx) Future<String>
sendTransaction(Envelope envelope) Future<String>
signMessage(Uint8List message) Future<Uint8List>
signTransaction(Envelope envelope) Future<Uint8List>
signTypedData(Map<String, dynamic> typedData) Future<Uint8List>
toString() String
A string representation of this object.
inherited
waitForTransaction(String txHash, {int confirmations = 1, Duration timeout = const Duration(minutes: 5)}) Future<Map<String, dynamic>>

Operators

operator ==(Object other) bool
The equality operator.
inherited