DelegatedAccount class abstract
ERC-4337 smart contract account that builds and signs UserOperations.
- Implementers
Constructors
Properties
- address → EvmAddr
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- ownerAddress → EvmAddr
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildInitCode(
) → Uint8List -
buildUserIntent(
{required EvmAddr target, required BigInt value, required Uint8List data, BigInt? maxFeePerGas, BigInt? maxPriorityFeePerGas}) → Future< UserIntent> -
encodeBatchExecute(
List< EvmAddr> targets, List<BigInt> values, List<Uint8List> datas) → Uint8List -
encodeExecute(
EvmAddr target, BigInt value, Uint8List data) → Uint8List -
getNonce(
) → Future< BigInt> -
isDeployed(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signUserOpHash(
Uint8List hash) → Future< Uint8List> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited