FungibleToken class
ERC-20 interface.
Constructors
- FungibleToken(DeployedContract contract)
- FungibleToken.at(EvmAddr address)
-
factory
- FungibleToken.atHex(String address)
-
factory
Properties
- address → EvmAddr
-
no setter
- contract → DeployedContract
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allowance(
EvmAddr owner, EvmAddr spender) → CallBuilder -
approve(
EvmAddr spender, BigInt amount) → InvokeBuilder -
balanceOf(
EvmAddr owner) → CallBuilder -
decimals(
) → CallBuilder -
encodeApprove(
EvmAddr spender, BigInt amount) → Uint8List -
encodeTransfer(
EvmAddr to, BigInt amount) → Uint8List -
name(
) → CallBuilder -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
symbol(
) → CallBuilder -
toString(
) → String -
A string representation of this object.
inherited
-
totalSupply(
) → CallBuilder -
transfer(
EvmAddr to, BigInt amount) → InvokeBuilder -
transferFrom(
EvmAddr from, EvmAddr to, BigInt amount) → InvokeBuilder
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited