KeyAgent class abstract
Signing interface: in-memory, hardware, or remote.
- Implementers
Constructors
- KeyAgent()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAddress(
) → Future< EvmAddr> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signHash(
Uint8List hash32) → Future< Uint8List> - Sign a raw 32-byte hash. Returns 65-byte signature (r + s + v).
-
signMessage(
Uint8List message) → Future< Uint8List> - EIP-191 personal_sign. Returns 65-byte signature (r + s + v).
-
signTransaction(
Envelope envelope) → Future< Uint8List> -
signTypedData(
Map< String, dynamic> typedData) → Future<Uint8List> - EIP-712 typed data signing. Returns 65-byte signature (r + s + v).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited