MultiToken class
ERC-1155 interface.
Constructors
- MultiToken(DeployedContract contract)
- MultiToken.at(EvmAddr address)
-
factory
- MultiToken.atHex(String address)
-
factory
Properties
- address → EvmAddr
-
no setter
- contract → DeployedContract
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
balanceOf(
EvmAddr owner, BigInt id) → CallBuilder -
balanceOfBatch(
List< EvmAddr> owners, List<BigInt> ids) → CallBuilder -
isApprovedForAll(
EvmAddr owner, EvmAddr operator_) → CallBuilder -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
safeBatchTransferFrom(
EvmAddr from, EvmAddr to, List< BigInt> ids, List<BigInt> amounts, Uint8List data) → InvokeBuilder -
safeTransferFrom(
EvmAddr from, EvmAddr to, BigInt id, BigInt amount, Uint8List data) → InvokeBuilder -
setApprovalForAll(
EvmAddr operator_, bool approved) → InvokeBuilder -
toString(
) → String -
A string representation of this object.
inherited
-
uri(
BigInt tokenId) → CallBuilder
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited