MultichainNames class
ENSIP-9 multi-coin address resolution.
Resolves ENS names to addresses on any chain via SLIP-44 coin types.
Constructors
- MultichainNames(String name)
Properties
Methods
-
getAddress(
int coinType) → Future< Uint8List?> -
getEvmAddress(
int chainId) → Future< Uint8List?> -
ENSIP-11: EVM coin type is
0x80000000 | chainId. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAddress(
int coinType, Uint8List address) → Future< void> -
setEvmAddress(
int chainId, Uint8List address) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
coinTypeToChainId(
int coinType) → int? -
encodeMultichainAddrCall(
Uint8List node, int coinType) → Uint8List -
encodeSetAddrCall(
Uint8List node, int coinType, Uint8List address) → Uint8List