NameResolver class
ENS name resolution and reverse lookup.
Constructors
- NameResolver({EvmAddr? registryAddress})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- registryAddress → EvmAddr
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
String name) → Future< EvmAddr?> -
resolveContentHash(
String name) → Future< Uint8List?> -
resolverFor(
String name) → Future< EvmAddr?> -
reverseLookup(
EvmAddr address) → Future< String?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
encodeAddrCall(
Uint8List node) → Uint8List -
encodeContenthashCall(
Uint8List node) → Uint8List -
encodeNameCall(
Uint8List node) → Uint8List -
encodeResolverCall(
Uint8List node) → Uint8List -
namehash(
String name) → Uint8List