PersonalSign class
EIP-191 personal message signing.
Prefixes with "\x19Ethereum Signed Message:\n<length>" before keccak256.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
messageHash(
Uint8List message) → Uint8List -
messageHashString(
String message) → Uint8List -
recoverPublicKey(
Uint8List message, Uint8List signature65) → Uint8List -
sign(
Uint8List message, SecretKey key) → Uint8List - Returns 65 bytes: r (32) + s (32) + v (1, where v = recId + 27).
-
signString(
String message, SecretKey key) → Uint8List