SolEvent class
Constructors
Properties
- anonymous → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indexed
→ List<
bool> -
final
-
inputNames
→ List<
String> -
final
-
inputs
→ List<
SolType> -
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String
-
no setter
- topic0 → Uint8List
-
no setter
Methods
-
decode(
List< Uint8List> topics, Uint8List data) → List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited