SolFunction class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputNames
→ List<
String> -
final
-
inputs
→ List<
SolType> -
final
- isReadOnly → bool
-
no setter
- name → String
-
final
-
outputNames
→ List<
String> -
final
-
outputs
→ List<
SolType> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selector → Uint8List
-
no setter
- signature → String
-
no setter
- stateMutability → String
-
final
Methods
-
decodeResult(
Uint8List data) → List -
encodeCall(
List args) → Uint8List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited