SolParser class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String jsonAbi) → ParsedAbi -
parseFunction(
String sig) → SolFunction -
Parse a human-readable signature like
"function transfer(address to, uint256 amount) returns (bool)". -
resolveType(
String type, [List? components]) → SolType