TokenGasSponsor class
ERC-20 paymaster -- lets users pay gas in tokens instead of ETH.
- Implemented types
Constructors
- TokenGasSponsor({required String paymasterAddress, required String tokenAddress})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- paymasterAddress → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenAddress → String
-
final
Methods
-
buildPaymasterAndData(
) → Uint8List -
estimateTokenCost(
UserIntent userOp, BigInt exchangeRate) → BigInt -
getPaymasterData(
UserIntent userOp) → Future< Uint8List> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sponsor(
UserIntent userOp) → Future< UserIntent> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
willSponsor(
UserIntent userOp) → Future< bool> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited