TrezorDevice class abstract
- Inheritance
-
- Object
- HardwareDevice
- TrezorDevice
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
int msgType, Uint8List payload) → Future< (int, Uint8List)> -
connectDevice(
) → Future< void> -
inherited
-
disconnect(
) → Future< void> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scanForDevices(
) → Future< List< HardwareDevice> > -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
forFirmware(
TrezorFeatures features, {required String hidPath}) → TrezorHardwareWalletDevice