MoneroStandardAddr class
Standard address: net_byte(1) || spend_key(32) || view_key(32) || checksum(4).
- Implemented types
Constructors
- MoneroStandardAddr(Uint8List spendKey, Uint8List viewKey)
Properties
- addrType → MoneroAddrType
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- publicSpendKey → Uint8List
-
final
- publicViewKey → Uint8List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
int networkByte) → String -
override
-
encodeMainnet(
) → String -
encodeStagenet(
) → String -
encodeTestnet(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited