StealthAddress class
One-time output key: P = Hs(r*viewKey || i)G + spendKey. Recipient detects via P' = Hs(viewPrivR || i)*G + spendKey, checks P'==P.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
deriveOutputKey(
{required Uint8List txSecretKey, required Uint8List recipientViewKey, required Uint8List recipientSpendKey, required int outputIndex}) → Uint8List -
deriveOutputPrivateKey(
{required Uint8List privateSpendKey, required Uint8List privateViewKey, required Uint8List txPublicKey, required int outputIndex}) → Uint8List - x = Hs(viewKey * R || i) + spendKey (mod l)
-
isOurOutput(
{required Uint8List privateViewKey, required Uint8List publicSpendKey, required Uint8List txPublicKey, required Uint8List outputKey, required int outputIndex}) → bool -
txPublicKey(
Uint8List txSecretKey) → Uint8List